@@ -197,6 +197,13 @@ class UncivGame(parameters: UncivGameParameters) : Game() {
 
         onlineMultiplayer = OnlineMultiplayer()
 
+        // Check if the server is available in case the feature set has changed
+        try {
+            onlineMultiplayer.checkServerStatus()
+        } catch (ex: Exception) {
+            debug("Couldn't connect to server: " + ex.message)
+        }
+
         ImageGetter.resetAtlases()
         ImageGetter.setNewRuleset(ImageGetter.ruleset)  // This needs to come after the settings, since we may have default visual mods
         if (settings.tileSet !in ImageGetter.getAvailableTilesets()) { // If one of the tilesets is no longer available, default back
@@ -542,7 +549,7 @@ class UncivGame(parameters: UncivGameParameters) : Game() {
 
     companion object {
         //region AUTOMATICALLY GENERATED VERSION DATA - DO NOT CHANGE THIS REGION, INCLUDING THIS COMMENT
-        val VERSION = Version("4.4.19", 818)
+        val VERSION = Version("4.5.0", 819)
         //endregion
 
         lateinit var Current: UncivGame
